@@ -183,7 +183,7 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
   g <- switch(key,
               hn    = keyfct.hn(distance, key.scale),
               hr    = keyfct.hz(distance, key.scale, key.shape),
-              unif  = rep(1/(width-left), length(distance)),
+              unif  = rep(1, length(distance)),
               gamma = keyfct.gamma(distance, key.scale, key.shape),
               th1   = keyfct.th1(distance, key.scale, key.shape),
               th2   = keyfct.th2(distance, key.scale, key.shape),
@@ -199,7 +199,7 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
 
     # Find out if we are scaling by width or by key scale
     if(adj.scale == "width"){
-      scaling <- width-left
+      scaling <- width
     }else{
       scaling <- key.scale
     }
@@ -232,7 +232,7 @@ detfct <- function(distance, ddfobj, select=NULL, index=NULL, width=NULL,
       key.val.0 <- switch(key,
                           hn    = keyfct.hn(zeros, key.scale),
                           hr    = keyfct.hz(zeros, key.scale, key.shape),
-                          unif  = rep(1/(width-left), length(zeros)),
+                          unif  = rep(1, length(zeros)),
                           gamma = keyfct.gamma(zeros, key.scale, key.shape),
                           th1   = keyfct.th1(zeros, key.scale, key.shape),
                           th2   = keyfct.th2(zeros, key.scale, key.shape))
