@@ -236,7 +236,10 @@ predict.ds <- function(object, newdata=NULL, compute=FALSE, int.range=NULL,
       int.range <- int.range[!naind, , drop=FALSE]
       # reset newdata to be the right thing
       newdata <- newdata[(nrow(model_dat)+1):nrow(newdata), , drop=FALSE]
-
+      # Implement fix for hr cov models when se.fit = TRUE (above line of code omits covariate values from newdata)
+      if(ddfobj$type == "hr" &&  se.fit && length(all.vars(as.formula(model$ds$aux$ddfobj[["scale"]]$formula))) > 0){
+        newdata <- newdata_save
+      }
     }
 
     # Compute integral of fitted detection function using either logistic or
